'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

/**
 * Define a struct error.
 *
 * @type {StructError}
 */

class StructError extends TypeError {

  constructor(attrs) {
    const { data, value, type, path = [] } = attrs;
    const message = `Expected a value of type "${type}" ${path.length ? `for \`${path.join('.')}\`` : ''} but received \`${value}\`.`;
    super(message);
    this.data = data;
    this.path = path;
    this.value = value;
    this.type = type;
    this.errors = [this];
    Error.captureStackTrace(this, this.constructor);
  }

}

/**
 * Export.
 *
 * @type {StructError}
 */

exports.default = StructError;